@@ -1,15 +1,19 @@
-"""Example of using pydantic_cli leveraging the Pydantic Field
+"""
+Example of using pydantic_cli leveraging the Pydantic Field to add rich metadata
+that will be communicated in the output of `--help`.
+
+Note, that this leverages Pydantic's underlying validation mechanism. For example,
+`max_records` must be > 0.
 """
 from typing import Optional
 from pydantic import BaseModel, Field
 
-from pydantic_cli.examples import ConfigDefaults
+from pydantic_cli.examples import ExampleConfigDefaults
 from pydantic_cli import run_and_exit
 
 
 class Options(BaseModel):
-
-    class Config(ConfigDefaults):
+    class Config(ExampleConfigDefaults):
         pass
 
     input_file: str = Field(
@@ -17,7 +21,7 @@ class Options(BaseModel):
         title="Input File",
         description="Path to the input file",
         # required=True, # this is implicitly set by ...
-        extras={'cli': ("-f", "--input-file")}
+        extras={"cli": ("-f", "--input-file")},
     )
 
     max_records: int = Field(
@@ -25,14 +29,14 @@ class Options(BaseModel):
         title="Max Records",
         description="Max number of records",
         gt=0,
-        extras={'cli': ('-m', )},
+        extras={"cli": ("-m",)},
     )
 
     min_filter_score: float = Field(
         ...,
         title="Min Score",
         description="Minimum Score Filter that will be applied to the records",
-        extras={'cli': ('-s', )},
+        extras={"cli": ("-s",)},
         gt=0
         # or extras={'cli': ('-s', '--min-filter-score', )}
     )
@@ -42,7 +46,7 @@ class Options(BaseModel):
         title="Max Score",
         description="Maximum Score Filter that will be applied to the records",
         gt=0,
-        extras={'cli': ('-S', )}
+        extras={"cli": ("-S",)}
         # or extras={'cli': ('-S', '--min-filter-score', )}
     )
 
@@ -56,4 +60,4 @@ def example_runner(opts: Options) -> int:
 
 
 if __name__ == "__main__":
-    run_and_exit(Options, example_runner, description=__doc__, version='0.1.0')
\ No newline at end of file
+    run_and_exit(Options, example_runner, description=__doc__, version="0.1.0")
