@@ -1,7 +1,9 @@
 """
 Simple Example of using Pydantic to generate a CLI
 
-This example will generate a CLI tool with 1 positional argument and one optional boolean arg
+This example will generate a CLI tool with 1 required argument and one optional boolean arg.
+
+Note the optional boolean value must be supplied as `--run_training False`
 """
 from pydantic import BaseModel
 
@@ -19,4 +21,4 @@ def example_runner(opts: Options) -> int:
 
 
 if __name__ == "__main__":
-    run_and_exit(Options, example_runner, description=__doc__, version='0.1.0')
+    run_and_exit(Options, example_runner, description=__doc__, version="0.1.0")
